@@ -112,6 +112,13 @@ class FreeStubTests(TestCase):
 
         assert_that(stub.foo(1), is_(1))
 
+    # new on 1.8.2
+    def test_returns_input_two_args(self):
+        with Stub() as stub:
+            stub.foo(ANY_ARG).returns_input()
+
+        assert_that(stub.foo(1, 2), is_((1, 2)))
+
     def test_raises(self):
         with self.stub:
             self.stub.foo(2).raises(SomeException)
@@ -1004,6 +1011,21 @@ class StubDelegateTests(TestCase):
             expected = "delegates() must be called with callable or iterable instance (got 'None' instead)"
             assert_that(str(e), contains_string(expected))
 
+    # FIXME: explain in docs
+    def test_delegates_with_params(self):
+        with self.stub:
+            self.stub.foo(anything()).delegates(lambda x: x + 2)
+
+        assert_that(self.stub.foo(3), is_(5))
+
+    # new on 1.8.2
+    # FIXME: include in docs
+    def test_delegate_to_dict(self):
+        with self.stub:
+            self.stub.foo(anything()).delegates({0: 2, 1: 7, 2: 12})
+
+        assert_that(self.stub.foo(1), is_(7))
+
 
 class MockDelegateTest(TestCase):
     def setUp(self):
@@ -1200,7 +1222,7 @@ class PropertyTests(TestCase):
         assert_that(collaborator.prop, is_(20))
 
 
-# FIXME: new on 1.8
+# new on 1.8
 class PropertyMockTests(TestCase):
     def test_mock_get(self):
         with Mock(ObjCollaborator) as mock:
@@ -1433,8 +1455,17 @@ class ProxySpy_default_behavior_tests(TestCase):
         assert_that(spy.hello(), is_(40))
 
 
+class orphan_spy_method_tests(TestCase):
+    # new on 1.8.2
+    # issue 21
+    def test_spy(self):
+        m = method_returning(3)
+        m()
+        assert_that(m, called())
+
+
 # FIXME: new on tip
-class orphan_methods_tests(TestCase):
+class new_style_orphan_methods_tests(TestCase):
     def setUp(self):
         self.obj = Collaborator()
 
@@ -1479,6 +1510,22 @@ class orphan_methods_tests(TestCase):
 #        assert_that(spy.method, called().times(3))
 
 
+class custom_types_tests(TestCase):
+    # issue 22
+    def test_custom_equality_comparable_objects(self):
+        class A(object):
+            def __init__(self, value):
+                self.value = value
+
+            def __eq__(self, other):
+                return self.value == other.value
+
+        with Stub() as stub:
+            stub.foo(A(1)).returns(A(1))
+
+        self.assertEquals(A(1), stub.foo(A(1)))
+
+
 class when_tests(TestCase):
     def test_stub_when(self):
         stub = Stub()
